aboutsummaryrefslogtreecommitdiffstats
path: root/lib/agent/project-interface.go
diff options
context:
space:
mode:
Diffstat (limited to 'lib/agent/project-interface.go')
-rw-r--r--lib/agent/project-interface.go15
1 files changed, 8 insertions, 7 deletions
diff --git a/lib/agent/project-interface.go b/lib/agent/project-interface.go
index c9e9ec5..0d6bb1a 100644
--- a/lib/agent/project-interface.go
+++ b/lib/agent/project-interface.go
@@ -4,11 +4,12 @@ import "github.com/iotbzh/xds-agent/lib/apiv1"
// IPROJECT Project interface
type IPROJECT interface {
- Add(cfg apiv1.ProjectConfig) (*apiv1.ProjectConfig, error) // Add a new project
- Delete() error // Delete a project
- GetProject() *apiv1.ProjectConfig // Get project public configuration
- UpdateProject(prj apiv1.ProjectConfig) (*apiv1.ProjectConfig, error) // Update project configuration
- GetServer() *XdsServer // Get XdsServer that holds this project
- Sync() error // Force project files synchronization
- IsInSync() (bool, error) // Check if project files are in-sync
+ Add(cfg apiv1.ProjectConfig) (*apiv1.ProjectConfig, error) // Add a new project
+ Setup(prj apiv1.ProjectConfig) (*apiv1.ProjectConfig, error) // Local setup of the project
+ Delete() error // Delete a project
+ GetProject() *apiv1.ProjectConfig // Get project public configuration
+ Update(prj apiv1.ProjectConfig) (*apiv1.ProjectConfig, error) // Update project configuration
+ GetServer() *XdsServer // Get XdsServer that holds this project
+ Sync() error // Force project files synchronization
+ IsInSync() (bool, error) // Check if project files are in-sync
}